summaryrefslogtreecommitdiff
path: root/lisp/calculator.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/calculator.el')
-rw-r--r--lisp/calculator.el22
1 files changed, 10 insertions, 12 deletions
diff --git a/lisp/calculator.el b/lisp/calculator.el
index 6e935f246a..b1a3f9e075 100644
--- a/lisp/calculator.el
+++ b/lisp/calculator.el
@@ -43,8 +43,6 @@
;;; History:
;; I hate history.
-(eval-when-compile (require 'cl))
-
;;;=====================================================================
;;; Customization:
@@ -717,17 +715,17 @@ See the documentation for `calculator-mode' for more information."
(cond
((not (get-buffer-window calculator-buffer))
(let ((window-min-height 2))
;; maybe leave two lines for our window because of the normal
;; `raised' modeline in Emacs 21
(select-window
(split-window-below
;; If the modeline might interfere with the calculator buffer,
;; use 3 lines instead.
(if (and (fboundp 'face-attr-construct)
(let* ((dh (plist-get (face-attr-construct 'default) :height))
- (mf (face-attr-construct 'modeline))
+ (mf (face-attr-construct 'mode-line))
(mh (plist-get mf :height)))
;; If the modeline is shorter than the default,
;; stick with 2 lines. (It may be necessary to
;; check how much shorter.)
(and
@@ -739,7 +737,7 @@ See the documentation for `calculator-mode' for more information."
(not (integerp mh))
(< mh 1))))
(or
;; If the modeline is taller than the default,
;; use 3 lines.
(and (integerp dh)
(integerp mh)
@@ -747,7 +745,7 @@ See the documentation for `calculator-mode' for more information."
(and (numberp mh)
(not (integerp mh))
(> mh 1))
;; If the modeline has a box with non-negative line-width,
;; use 3 lines.
(let* ((bx (plist-get mf :box))
(lh (plist-get bx :line-width)))
@@ -755,8 +753,8 @@ See the documentation for `calculator-mode' for more information."
(or
(not lh)
(> lh 0))))
- ;; If the modeline has an overline, use 3 lines.
- (plist-get (face-attr-construct 'modeline) :overline)))))
+ ;; If the mode line has an overline, use 3 lines.
+ (plist-get (face-attr-construct 'mode-line) :overline)))))
-3 -2)))
(switch-to-buffer calculator-buffer)))
((not (eq (current-buffer) calculator-buffer))
@@ -717,17 +715,17 @@ See the documentation for `calculator-mode' for more information."
((not (get-buffer-window calculator-buffer))
(let ((window-min-height 2))
- ;; maybe leave two lines for our window because of the normal
- ;; `raised' modeline in Emacs 21
+ ;; maybe leave two lines for our window because of the
+ ;; normal `raised' mode line
(select-window
(split-window-below
@@ -717,17 +715,17 @@ See the documentation for `calculator-mode' for more information."
(select-window
(split-window-below
- ;; If the modeline might interfere with the calculator buffer,
- ;; use 3 lines instead.
+ ;; If the mode line might interfere with the calculator
+ ;; buffer, use 3 lines instead.
(if (and (fboundp 'face-attr-construct)
(let* ((dh (plist-get (face-attr-construct 'default) :height))
@@ -717,17 +715,17 @@ See the documentation for `calculator-mode' for more information."
(mh (plist-get mf :height)))
- ;; If the modeline is shorter than the default,
+ ;; If the mode line is shorter than the default,
;; stick with 2 lines. (It may be necessary to
;; check how much shorter.)
@@ -739,7 +737,7 @@ See the documentation for `calculator-mode' for more information."
(< mh 1))))
(or
- ;; If the modeline is taller than the default,
+ ;; If the mode line is taller than the default,
;; use 3 lines.
(and (integerp dh)
@@ -747,7 +745,7 @@ See the documentation for `calculator-mode' for more information."
(not (integerp mh))
(> mh 1))
- ;; If the modeline has a box with non-negative line-width,
+ ;; If the mode line has a box with non-negative line-width,
;; use 3 lines.
(let* ((bx (plist-get mf :box))